IdeSourceMap {
  padding-left: 13px;
  padding-right: 13px;
}
IdeSourceMap:dir(ltr) {
  border-left: 1px solid alpha(@borders, .3);
}
IdeSourceMap:dir(rtl) {
  border-right: 1px solid alpha(@borders, .3);
}
IdeSourceMap textview.GtkSourceMap {
  background: transparent;
  font-family: BuilderBlocks;
  font-size: 1.75pt;
  line-height: 5px;
  margin: 0;
}
IdeSourceMap textview.GtkSourceMap slider {
  padding-left: 13px;
  padding-right: 13px;
  margin-left: -13px;
  margin-right: -13px;
}
IdeSourceMap textview.GtkSourceMap border,
IdeSourceMap textview.GtkSourceMap gutter {
  background: transparent;
}

.hover-display-row:not(:last-child) {
  border-bottom: 1px solid @borders;
}

.hover-display-row {
  padding: 6px;
  padding-left: 12px;
  padding-right: 12px;
}

GtkSourceAssistant.hover-assistant {
  background: @popover_bg_color;
  color: @popover_fg_color;
  box-shadow: 0 3px 14px 7px @shadow_color,
              0 0 0 1px mix(@popover_bg_color, @popover_fg_color, .15),
	      /* give a bit more pointer space to avoid flickering display */
	      0 0 20px 20px transparent;
}
