:root {
  --text-color: #24292e;
  --hyperlink-color: #0366d6;
  --codeblock-color: rgba(0, 0, 0, 0.08);
  --blockquote-border-color: rgba(0, 0, 0, 0.25);
  --code-color: rgba(0, 0, 0, 0.08);
  --table-border-color: #24292e;
}

@media (prefers-color-scheme: dark) {
  :root {
    --text-color: #dfdfdf;
    --hyperlink-color: lightblue;
    --codeblock-color: rgba(255, 255, 255, 0.08);
    --blockquote-border-color: rgba(255, 255, 255, 0.25);
    --code-color: rgba(255, 255, 255, 0.08);
    --table-border-color: #dfdfdf;
  }
}

body {
  color: var(--text-color);
  max-width: 1000px;
  margin: 0 auto;
  padding: 10px;
  overflow-wrap: break-word;
}

a {
  color: var(--hyperlink-color);
  transition: all 0.125s ease;
}

a:hover {
  opacity: 0.75;
}

blockquote {
  padding: 0 0.5em;
  border-left: 8px solid var(--blockquote-border-color);
  margin: 0;
  border-radius: 2.5px;
}

code {
  font-size: larger;
  overflow: scroll;
}

pre {
  background-color: var(--codeblock-color);
  border-radius: 3px;
  line-height: 1.45;
  overflow: auto;
  padding: 16px;
}

code:not(pre code) {
  position: relative;
  padding: 0 0.5em 0;
  max-height: 750px;
  border-radius: 5px;
  background-color: var(--code-color);
}

table {
  table-layout: fixed;
  width: 100%;
  border-collapse: collapse;
}

img {
  display: block;
  max-width: 100%;
}

table, th, td {
  border: 1.5px solid var(--table-border-color);
}

th, td {
  padding: 7.5px;
}

#markdown-source {
  display: none;
}
